# patent.py - Connection to Google Patent API
#
# Copyright (C) Optibrium Ltd 2022
# stardrop-support@optibrium.com
#
# This script opens a web browser and retrieves patent information 
# from patents.google.com 

# For advice or feedback, contact stardrop-support@optibrium.com

import urllib.request, urllib.parse, urllib.error
import webbrowser
from PythonQt import ComboBoxSelector

def getData(appui):
	mol = appui.getCurrentMolecule()
	if len(mol) == 0:
		appui.show('Please select one molecule!')
		return
	
	cb = ComboBoxSelector()
	cb.setWindowTitle('Google Patents & Scholar')
	cb.setText('Choose options for searching')
	options = {}
	options['method'] = ['Structure Match', 
						'Substructure Search', 
						'Similarity Search']
	options['source'] = ['Google Patents', 'Google Scholar', 'Both']
	cb.setOptions('Matching method:', options['method'])
	cb.addOptions('Data source:', options['source'])
	
	if cb.run():
		m = cb.getSelectedOption(0)
		s = cb.getSelectedOption(1)
	else:
		return
	
	urlbase = 'https://patents.google.com/?q='
	smiles = 'SMILES=' + mol
	if m == 'Structure Matching':
		match = smiles
	elif m == 'Substructure Searching':
		match = 'SSS=' + smiles
	else:
		match = '~' + smiles
	method = urllib.parse.quote(match)
	
	if s == 'Google Patents':
		source = ''
	elif s == 'Google Scholar':
		source = '&patents=false&scholar'
	else:
		source = '&scholar'
	
	webbrowser.open_new(urlbase + method + source)
	
	return

def get_stardrop_definitions():
	definitions = [
		{
			'script_name': 'Google Patent and Scholar',
			'callback': getData
		}
	]

	return definitions
